package com.zg.project.wisdom.service;

import java.util.List;
import com.zg.project.wisdom.domain.RkBill;
import com.zg.project.wisdom.domain.dto.BorrowReturnDTO;
import com.zg.project.wisdom.domain.dto.RkBillCreateDTO;

/**
 * 库存单据Service接口
 * 
 * @author zg
 * @date 2026-01-20
 */
public interface IRkBillService 
{
    /**
     * 查询库存单据
     * 
     * @param id 库存单据主键
     * @return 库存单据
     */
    public RkBill selectRkBillById(Long id);

    /**
     * 查询库存单据列表
     * 
     * @param rkBill 库存单据
     * @return 库存单据集合
     */
    public List<RkBill> selectRkBillList(RkBill rkBill);

    /**
     * 新增库存单据
     * 
     * @param rkBill 库存单据
     * @return 结果
     */
    public int insertRkBill(RkBill rkBill);

    int insertRkBillAndDetail(RkBillCreateDTO dto);

    /**
     * 向已有单据追加入库明细
     */
    int appendRkBillDetail(RkBillCreateDTO dto);

    /**
     * 修改库存单据
     * 
     * @param rkBill 库存单据
     * @return 结果
     */
    public int updateRkBill(RkBill rkBill);

    /**
     * 批量删除库存单据
     * 
     * @param ids 需要删除的库存单据主键集合
     * @return 结果
     */
    public int deleteRkBillByIds(Long[] ids);

    /**
     * 删除库存单据信息
     * 
     * @param id 库存单据主键
     * @return 结果
     */
    public int deleteRkBillById(Long id);

    /**
     * 新增出库
     */
    int insertOutBillAndDetail(RkBillCreateDTO dto);

    /**
     * 还料入库
     */
    int returnBorrow(BorrowReturnDTO dto);
}
